#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shelly
version:              1.9.0
visibility:           public
id:                   shelly-1.9.0-23I2OAYyvltAzKMPCVOXy9
key:                  shelly-1.9.0-23I2OAYyvltAzKMPCVOXy9
license:              BSD-3-Clause
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/yesodweb/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.

    * has detailed and useful error messages

    * maintains its own environment, making it thread-safe.

    * is modern, using Text filepath/directory

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  f05138cf7705491fb01f46b962c421f0
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-8.10.5/site-local/shelly-1.9.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/shelly-1.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/shelly-1.9.0
hs-libraries:         HSshelly-1.9.0-23I2OAYyvltAzKMPCVOXy9
depends:
    async-2.2.3-6QbaQgrhqs02Gm74dJYuzp base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1 directory-1.3.6.0
    enclosed-exceptions-1.0.3-C03wyFlfKXD7wW5m5IDFTa exceptions-0.10.4
    filepath-1.4.2.1 lifted-async-0.10.2-6pZcCH6I8jt9dfdV2r56ON
    lifted-base-0.2.3.12-HsHHuUVdYcr6iiSvL0hwyv
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J mtl-2.2.2
    process-1.6.9.0 text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn unix-2.7.2.2
    unix-compat-0.5.3-1KqjYp6svTH6EdzCzH8QEz

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

